# Jupyter Community Call 09/27

**Date:** September 27, 2022, at 7am Pacific (in your [timezone](https://arewemeetingyet.com/Los%20Angeles/2022-09-27/7:00/Jupyter%20Community%20Call))

[**Discourse**](https://discourse.jupyter.org/t/jupyter-community-calls/668)

[**Youtube**](https://youtu.be/DDdwyQLWnUU)

**Please note:**
- Community calls are recorded and posted to this [playlist](https://www.youtube.com/playlist?list=PLUrHeD2K9Cmkoamm4NjLmvXC4Y6E1o8SP)
- These notes will be recorded and posted [here](https://jupyter.readthedocs.io/en/latest/community/community-call-notes/index.html)
- Everyone present is held to the [Jupyter Code of Conduct](https://jupyter.org/conduct)

## Purpose

Think of it as a monthly, virtual JupyterCon. It’s a place to announce and share fun things happening in the Jupyter community.

For more discussion on the format of these calls, see the thread [here](https://discourse.jupyter.org/t/reviving-the-all-jupyter-team-meetings/423).

## Short reports, celebrations, shout-outs

This is a place to make short announcements (without a need for discussion). 

* **[jupyterlite 0.1.0b13](https://github.com/jupyterlite/jupyterlite/blob/main/CHANGELOG.md#010b13)** is released, with support for [ipywidgets 8](https://github.com/jupyter-widgets/ipywidgets/releases/tag/8.0.0)

## Agenda Items

* Peter Vidos **[ipyvizzu-story](https://github.com/vizzuhq/ipyvizzu-story)** - A short intro of a new, open-source data storytelling tool for Jupyter Notebook.
    * Repo: https://github.com/vizzuhq/ipyvizzu-story
    * Example (HTML): https://vizzuhq.github.io/ipyvizzu-story/examples/demo/ipyvizzu-story_example.html
* **Yuze** Questions about Jupyter community in the APAC region

## Other Links Shared

This is a space to store links shared during community call discussions related to or separate from the agenda items.

- [Books by Alberto Cairo](https://en.wikipedia.org/wiki/Alberto_Cairo#Books)
- [Animated charts and story telling with IpyVizzu](https://discourse.holoviz.org/t/animated-charts-and-story-telling-with-ipyvizzu/3622)
- [Charting Data guidelines - Apple Human Interface Guidelines](https://developer.apple.com/design/human-interface-guidelines/patterns/charting-data)
- [Chartability](https://chartability.fizz.studio/)
- [Join the Vizzu Community Slack](https://join.slack.com/t/vizzu-community/shared_invite/zt-w2nqhq44-2CCWL4o7qn2Ns1EFSf9kEg)
- [JupyterHub team compass](https://github.com/jupyterhub/team-compass/)

## Attendees 

|   Name   |           Institution     | GitHub Handle|
|----------|---------------------------|--------------|
| AT Darian | QuantStack | @afshin |
| Alex Bozarth | IBM | @ajbozarth |
|Yuze Ma          |Alibaba Group           | @bobmayuze
|Wayne Decatur |Upstate Med. University | @fomightez
| Isabela Presedo-Floyd | Quansight Labs | @isabela-pf 

Plus 5 more